% Phonetic experiments with PsychoPy and PsychoJS
% Stefan Werner
% 2024-10-02 **ISAPh Tartu**

# Overview
- Intro
- Demo experiment
- Hands-on experiment 1
- Hands-on experiment 2: from scratch
- Online version of experiment 1

---

# PsychoPy is **open-source** software







- The developers are users themselves.
- Bugs are often fixed very quickly.
- The threshold for introducing new features is low.

# History of PsychoPy

From limited visual stimulus creation to all-purpose graphical experiment builder:

<https://blog.psychopy.org/general%20blog/psychopy_origins/>

# PsychoPy experiments versus Praat experiments



- intuitive setup

---

![](PRAATexp.png)

---

vs.

![](PPexp.png)

# PsychoPy experiments versus Praat experiments

- user-friendly interface
- intuitive setup
- pictures, videos, graphics
- microphone input responses
- dynamic setup (responses can control test structure, e.g. select or modify stimuli)
- no distinction between _ExperimentMFC_ and other scripts

# Examples of possible advanced applications

- Online speech elicitation
- Diadochokinetic tests with automatic analysis (using ASR plugin)
- Tests involving multimedia stimuli
- Adaptive threshold perception tests
- Inclusion of data from eyetracker, EEG or fMRI
- ...

# But there is nothing wrong with simpler tests



In fact, they should be so simple to implement that everyone in this room can do it!  
Soon...



# Getting help with PsychoPy

[discourse.psychopy.org](discourse.psychopy.org )


# Experiment structure



Please make sure you have Psychopy fired up!


# _Stroop_ experiment


# Experiment `soundtest1`



### Perception of Finnish consonant quantity

| short             | long                   |
| :-----------:     | :-----------:          |
| myyrä hai**s**ee  | myyrä hai**ss**ee      |
| *the mole stinks* | *the mole might stink* |
| (IND)             | (POT)                  |

---

![](myyra.png)

---

#### Four stimuli

- `haisee_48.wav`
- `haisee-intermediate_48.wav`
- `haissee-intermediate_48.wav`
- `haissee_48.wav`




**Where is the perceptual boundary?**






# Experiment `soundtest2`

### 4-way identification of Finnish vowel and consonant quantity



|        | V               | VV                  |
| :----  | :-------------: | :-----------:       |
| **C**  | tulee           | tuulee              |
|        | *comes*         | *it's windy*        |
| **CC** | tullee          | tuullee             |
|        | *might come*    | *it might be windy* |








# PsychoJS and Pavlovia




*PsychoJS* is a JavaScript library that makes it possible to run PsychoPy experiments in a browser.



*Pavlovia* is a web repository and launch platform for PsychoPy experiments.


# Pricing

- £0.24 per participant



or

- Site license: £1800 per year

# Running

<https://run.pavlovia.org/stefan_werner/test>

# What is (not) available online?

<https://www.psychopy.org/online/status.htm>


# Common problems

- Stimulus files
- File system paths
- Condition spreadsheets
- Screen coordinates
- Program preferences vs. experiment settings
- Component vs. routine (duration) settings


